.. _conversion:

******************************************
Conversion (`baseband_tasks.conversion`)
******************************************

`~baseband_tasks.conversion` contains a task for converting a real time stream
to a complex one.

.. _conversionn_api:

Reference/API
=============

.. automodapi:: baseband_tasks.conversion
   :no-inherited-members:
